==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/General/ServiceLaunchPortal.md <==
# ServiceLaunchPortal


```text
azure-4/Item/General/ServiceLaunchPortal
```

```text
include('azure-4/Item/General/ServiceLaunchPortal')
```



| Illustration | ServiceLaunchPortal | ServiceLaunchPortalCard | ServiceLaunchPortalGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceLaunchPortal.png) | ![illustration for ServiceLaunchPortal](../../../azure-4/Item/General/ServiceLaunchPortal.Local.png) | ![illustration for ServiceLaunchPortalCard](../../../azure-4/Item/General/ServiceLaunchPortalCard.Local.png) | ![illustration for ServiceLaunchPortalGroup](../../../azure-4/Item/General/ServiceLaunchPortalGroup.Local.png) |




## ServiceLaunchPortal

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortal
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortal('ServiceLaunchPortal', 'Service Launch Portal', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortal
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortal('ServiceLaunchPortal', 'Service Launch Portal', 'an optional tech label')
@enduml
```

## ServiceLaunchPortalCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortalCard
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortalCard('ServiceLaunchPortalCard', 'Service Launch Portal Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortalCard
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortalCard('ServiceLaunchPortalCard', 'Service Launch Portal Card', 'an optional description')
@enduml
```

## ServiceLaunchPortalGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortalGroup
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortalGroup('ServiceLaunchPortalGroup', 'Service Launch Portal Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortalGroup
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortalGroup('ServiceLaunchPortalGroup', 'Service Launch Portal Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/azure-4/Item/General/ServiceLaunchPortal.md <==
# ServiceLaunchPortal


```text
azure-4/Item/General/ServiceLaunchPortal
```

```text
include('azure-4/Item/General/ServiceLaunchPortal')
```



| Illustration | ServiceLaunchPortal | ServiceLaunchPortalCard | ServiceLaunchPortalGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceLaunchPortal.png) | ![illustration for ServiceLaunchPortal](../../../azure-4/Item/General/ServiceLaunchPortal.Local.png) | ![illustration for ServiceLaunchPortalCard](../../../azure-4/Item/General/ServiceLaunchPortalCard.Local.png) | ![illustration for ServiceLaunchPortalGroup](../../../azure-4/Item/General/ServiceLaunchPortalGroup.Local.png) |




## ServiceLaunchPortal

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortal
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortal('ServiceLaunchPortal', 'Service Launch Portal', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortal
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortal('ServiceLaunchPortal', 'Service Launch Portal', 'an optional tech label')
@enduml
```

## ServiceLaunchPortalCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortalCard
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortalCard('ServiceLaunchPortalCard', 'Service Launch Portal Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortalCard
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortalCard('ServiceLaunchPortalCard', 'Service Launch Portal Card', 'an optional description')
@enduml
```

## ServiceLaunchPortalGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortalGroup
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortalGroup('ServiceLaunchPortalGroup', 'Service Launch Portal Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceLaunchPortalGroup
include('azure-4/Item/General/ServiceLaunchPortal')

' renders the element
ServiceLaunchPortalGroup('ServiceLaunchPortalGroup', 'Service Launch Portal Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
